@@ -52,6 +52,7 @@ class DocCLI(CLI):
 
     # default ignore list for detailed views
     IGNORE = ('module', 'docuri', 'version_added', 'short_description', 'now_date', 'plainexamples', 'returndocs')
+    JSON_IGNORE = ('attributes',)
 
     def __init__(self, args):
 
@@ -209,19 +210,24 @@ class DocCLI(CLI):
                     # The doc section existed but was empty
                     continue
 
-                plugin_docs[plugin] = {'doc': doc, 'examples': plainexamples,
-                                       'return': returndocs, 'metadata': metadata}
+                plugin_docs[plugin] = DocCLI._combine_plugin_doc(plugin, plugin_type, doc, plainexamples, returndocs, metadata)
 
             if do_json:
                 # Some changes to how json docs are formatted
                 for plugin, doc_data in plugin_docs.items():
+
+                    for forbid in DocCLI.JSON_IGNORE:
+                        try:
+                            del plugin_docs[plugin]['doc'][forbid]
+                        except (KeyError, TypeError):
+                            pass
+
                     try:
                         doc_data['return'] = yaml.load(doc_data['return'])
                     except Exception:
                         pass
 
                 jdump(plugin_docs)
-
             else:
                 # Some changes to how plain text docs are formatted
                 text = []
@@ -234,7 +240,6 @@ class DocCLI(CLI):
 
                 if text:
                     DocCLI.pager(''.join(text))
-
         return 0
 
     @staticmethod
@@ -322,6 +327,19 @@ class DocCLI(CLI):
         doc['filename'] = filename
         return doc, plainexamples, returndocs, metadata
 
+    @staticmethod
+    def _combine_plugin_doc(plugin, plugin_type, doc, plainexamples, returndocs, metadata):
+        # generate extra data
+        if plugin_type == 'module':
+            # is there corresponding action plugin?
+            if plugin in action_loader:
+                doc['has_action'] = True
+            else:
+                doc['has_action'] = False
+
+        # return everything as one dictionary
+        return {'doc': doc, 'examples': plainexamples, 'return': returndocs, 'metadata': metadata}
+
     @staticmethod
     def format_plugin_doc(plugin, plugin_type, doc, plainexamples, returndocs, metadata):
         # assign from other sections
@@ -329,18 +347,6 @@ class DocCLI(CLI):
         doc['returndocs'] = returndocs
         doc['metadata'] = metadata
 
-        # generate extra data
-        if plugin_type == 'module':
-            # is there corresponding action plugin?
-            if plugin in action_loader:
-                doc['action'] = True
-            else:
-                doc['action'] = False
-
-        doc['now_date'] = datetime.date.today().strftime('%Y-%m-%d')
-        if 'docuri' in doc:
-            doc['docuri'] = doc[plugin_type].replace('_', '-')
-
         if context.CLIARGS['show_snippet'] and plugin_type == 'module':
             text = DocCLI.get_snippet_text(doc)
         else:
@@ -631,7 +637,7 @@ class DocCLI(CLI):
         except Exception:
             pass  # FIXME: not suported by plugins
 
-        if doc.pop('action', False):
+        if doc.pop('has_action', False):
             text.append("  * note: %s\n" % "This module has a corresponding action plugin.")
 
         if 'options' in doc and doc['options']:
